@@ -5,6 +5,7 @@ import requests
 import math
 from .auth import Auth
 from sys import getsizeof
+import math
 
 class _DataFrame:
     app_id = None
@@ -69,7 +70,7 @@ class _DataFrame:
         limit = 5000000 * 0.95 / 8
 
         averageSize = getsizeof(dataframe.to_json(orient="index")) / len(dataframe.index)
-        amountSent = amountToSent if ((limit / averageSize) > amountToSent) else int(math.floor(limit / averageSize))
+        amountSent = amountSent if ((limit / averageSize) > amountToSent) else int(math.floor(limit / averageSize))
 
         offset = response.json()["data"]["items"]
         count = 0
